@@ -6,7 +6,7 @@
 
 from .config import Config
 
-version = "0.9"
+version = "0.9.6"
 
 
 class NSONE:
@@ -40,6 +40,7 @@ class NSONE:
             self.config.loadFromFile(configFile)
 
     # REST INTERFACE
+
     def zones(self):
         """
         Return a new raw REST interface to zone resources
@@ -85,6 +86,24 @@ class NSONE:
         import nsone.rest.data
         return nsone.rest.data.Feed(self.config)
 
+    def monitors(self):
+        """
+        Return a new raw REST interface to monitors resources
+
+        :rtype: :py:class:`nsone.rest.monitoring.Monitors`
+        """
+        import nsone.rest.monitoring
+        return nsone.rest.monitoring.Monitors(self.config)
+
+    def plan(self):
+        """
+        Return a new raw REST interface to account plan
+
+        :rtype: :py:class:`nsone.rest.account.Plan`
+        """
+        import nsone.rest.account
+        return nsone.rest.account.Plan(self.config)
+
     # HIGH LEVEL INTERFACE
     def loadZone(self, zone, callback=None, errback=None):
         """
@@ -97,13 +116,18 @@ class NSONE:
         zone = nsone.zones.Zone(self.config, zone)
         return zone.load(callback=callback, errback=errback)
 
-    def createZone(self, zone, callback=None, errback=None, **kwargs):
+    def createZone(self, zone, zoneFile=None, callback=None, errback=None,
+                   **kwargs):
         """
         Create a new zone, and return an associated high level Zone object.
         Several optional keyword arguments are available to configure the SOA
         record.
 
+        If zoneFile is specified, upload the specific zone definition file
+        to populate the zone with.
+
         :param str zone: zone name, like 'example.com'
+        :param str zoneFile: absolute path of a zone file
         :keyword int retry: retry time
         :keyword int refresh: refresh ttl
         :keyword int expiry: expiry ttl
@@ -113,7 +137,8 @@ class NSONE:
         """
         import nsone.zones
         zone = nsone.zones.Zone(self.config, zone)
-        return zone.create(callback=callback, errback=errback, **kwargs)
+        return zone.create(zoneFile=zoneFile, callback=callback,
+                           errback=errback, **kwargs)
 
     def loadRecord(self, domain, type, zone=None, callback=None,
                    errback=None, **kwargs):
