@@ -90,12 +90,14 @@ class Zone(object):
         return self._rest.update(self.zone, callback=success, errback=errback,
                                  **kwargs)
 
-    def create(self, callback=None, errback=None, **kwargs):
+    def create(self, zoneFile=None, callback=None, errback=None, **kwargs):
         """
         Create a new zone. Pass a list of keywords and their values to
         configure. For the list of keywords available for zone configuration,
         see :attr:`nsone.rest.zones.Zones.INT_FIELDS` and
         :attr:`nsone.rest.zones.Zones.PASSTHRU_FIELDS`
+        If zoneFile is passed, it should be a zone text file on the local disk
+        that will be used to populate the created zone file.
         """
         if self.data:
             raise ZoneException('zone already loaded')
@@ -107,13 +109,18 @@ class Zone(object):
             else:
                 return self
 
-        return self._rest.create(self.zone, callback=success, errback=errback,
-                                 **kwargs)
+        if zoneFile:
+            return self._rest.import_file(self.zone, zoneFile,
+                                          callback=success, errback=errback,
+                                          **kwargs)
+        else:
+            return self._rest.create(self.zone, callback=success,
+                                     errback=errback, **kwargs)
 
     def __getattr__(self, item):
 
         if not item.startswith('add_'):
-            return None
+            raise AttributeError(item)
 
         # dynamic adding of various record types, e.g. add_A, add_CNAME, etc
         (_, rtype) = item.split('_', 2)
@@ -124,6 +131,19 @@ class Zone(object):
             return record.create(callback=callback, errback=errback, **kwargs)
         return add_X
 
+    def createLinkToSelf(self, new_zone, callback=None, errback=None,
+                         **kwargs):
+        """
+        Create a new linked zone, linking to ourselves. All records in this
+        zone will then be available as "linked records" in the new zone.
+
+        :param str new_zone: the new zone name to link to this one
+        :return: new Zone
+        """
+        zone = Zone(self.config, new_zone)
+        kwargs['link'] = self.data['zone']
+        return zone.create(callback=callback, errback=errback, **kwargs)
+
     def linkRecord(self, existing_domain, new_domain, rtype,
                    callback=None, errback=None, **kwargs):
 
